@@ -3,7 +3,7 @@ from hestia_earth.validation.validators.shared import value_difference
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import list_sum, non_empty_list, safe_parse_float, flatten
 
-from hestia_earth.validation.utils import _filter_list_errors, _value_range_error, _value_average, _node_year
+from hestia_earth.validation.utils import _filter_list_errors, _value_average, _node_year
 from hestia_earth.validation.gee import fetch_data
 from .shared import need_validate_coordinates
 
@@ -134,29 +134,6 @@ def validate_required_depths(site: dict, list_key: str):
     return _filter_list_errors(map(validate, enumerate(site.get(list_key, []))))
 
 
-def validate_value_min_max(measurements: list):
-    lookup = download_lookup('measurement.csv')
-
-    def validate(values: tuple):
-        index, measurement = values
-        term_id = measurement.get('term', {}).get('@id')
-        mininum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'minimum'), None)
-        maximum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'maximum'), None)
-        value = _value_average(measurement, None)
-        error = _value_range_error(value, mininum, maximum) if value is not None else False
-        return error is False or ({
-            'level': 'error',
-            'dataPath': f".measurements[{index}].value",
-            'message': f"should be above {mininum}"
-        } if error == 'minimum' else {
-            'level': 'error',
-            'dataPath': f".measurements[{index}].value",
-            'message': f"should be below {maximum}"
-        })
-
-    return _filter_list_errors(map(validate, enumerate(measurements)))
-
-
 def validate_term_unique(measurements: list):
     lookup = download_lookup('measurement.csv')
 
