@@ -3,7 +3,8 @@ from concurrent.futures import ThreadPoolExecutor
 from functools import reduce
 import re
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.tools import flatten, list_sum
+from hestia_earth.utils.tools import flatten, list_sum, safe_parse_float
+from hestia_earth.utils.lookup import download_lookup, get_table_value
 from hestia_earth.earth_engine.gee_utils import MAX_AREA_SIZE
 
 from hestia_earth.validation.geojson import get_geojson_area
@@ -11,7 +12,7 @@ from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id,
 from hestia_earth.validation.utils import (
     update_error_path, _filter_list_errors, _next_error, _value_average,
     _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key,
-    _list_except_item, _dict_without_key, _hash_dict
+    _list_except_item, _dict_without_key, _hash_dict, _value_range_error
 )
 
 
@@ -89,32 +90,42 @@ def validate_list_dates_length(node: dict, list_key: str):
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
 
 
-def _compare_min_max(value1, value2): return value1 <= value2
+def _is_value_below(value1, value2):
+    compare_lists = isinstance(value1, list) and isinstance(value2, list)
+    return any([value1 is None, value2 is None]) or (
+        _is_list_value_below(value1, value2) if compare_lists else value1 <= value2
+    )
 
 
-def _compare_list_min_max(list1: list, list2: list):
-    def compare_enum(index: int):
-        valid = _compare_min_max(list1[index], list2[index])
-        return True if valid is True else index
+def _is_list_value_below(list1: list, list2: list):
+    def compare_enum(index: int): return _is_value_below(list1[index], list2[index])
 
     return len(list1) != len(list2) or \
-        next((x for x in list(map(compare_enum, range(len(list1)))) if x is not True), True)
+        next((x for x in list(map(compare_enum, range(len(list1)))) if x is not True), True) is True
 
 
-def validate_list_min_max(node: dict, list_key: str):
+def validate_list_value_between_min_max(node: dict, list_key: str):
     def validate(values: tuple):
-        index, value = values
-        min = value.get('min', 0)
-        max = value.get('max', 0)
-        skip_compare = (
-            isinstance(min, list) and not isinstance(max, list)
-        ) or (
-            isinstance(max, list) and not isinstance(min, list)
-        )
-        compare_lists = isinstance(min, list) and isinstance(max, list)
-        is_valid = True if skip_compare else \
-            _compare_list_min_max(min, max) if compare_lists else _compare_min_max(min, max)
-        return is_valid is True or {
+        index, blank_node = values
+        min = blank_node.get('min')
+        max = blank_node.get('max')
+        value = blank_node.get('value')
+
+        return all([_is_value_below(value, max), _is_value_below(min, value)]) or {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].value",
+            'message': 'must be between min and max'
+        }
+
+    return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
+
+
+def validate_list_min_below_max(node: dict, list_key: str):
+    def validate(values: tuple):
+        index, blank_node = values
+        min = blank_node.get('min')
+        max = blank_node.get('max')
+        return _is_value_below(min, max) or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].max",
             'message': 'must be greater than min'
@@ -123,6 +134,29 @@ def validate_list_min_max(node: dict, list_key: str):
     return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
+def validate_list_min_max_lookup(node: dict, list_key: list, list_key_field='value'):
+    def validate(values: tuple):
+        index, blank_node = values
+        term_id = blank_node.get('term', {}).get('@id')
+        term_type = blank_node.get('term', {}).get('termType')
+        lookup = download_lookup(f"{term_type}.csv")
+        mininum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'minimum'), None)
+        maximum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'maximum'), None)
+        value = _value_average(blank_node, None, list_key_field)
+        error = _value_range_error(value, mininum, maximum) if value is not None else False
+        return error is False or ({
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].{list_key_field}",
+            'message': f"should be above {mininum}"
+        } if error == 'minimum' else {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}].{list_key_field}",
+            'message': f"should be below {maximum}"
+        })
+
+    return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
+
+
 def validate_nodes_duplicates(node: dict, node_by_hash: dict):
     node_without_id = _dict_without_key(node, 'id')
     key = _hash_dict(node_without_id)
