@@ -10,15 +10,15 @@ from hestia_earth.validation.validators.cycle import (
     validate_sum_aboveGroundCropResidue,
     validate_crop_residue_completeness,
     validate_siteDuration,
-    validate_otherSites_length,
-    validate_otherSites_cycleDuration
+    validate_otherSites_cycleDuration,
+    validate_possibleCoverCrop
 )
 
 
 def test_validate_valid():
     with open(f"{fixtures_path}/cycle/valid.json") as f:
         node = json.load(f)
-    assert validate_cycle(node) == [True] * 48
+    assert validate_cycle(node) == [True] * 52
 
 
 def test_validate_cycle_dates_valid():
@@ -194,22 +194,6 @@ def test_validate_siteDuration_invalid():
     }
 
 
-def test_validate_otherSites_length_valid():
-    with open(f"{fixtures_path}/cycle/otherSites/length/valid.json") as f:
-        data = json.load(f)
-    assert validate_otherSites_length(data) is True
-
-
-def test_validate_otherSites_length_invalid():
-    with open(f"{fixtures_path}/cycle/otherSites/length/invalid.json") as f:
-        data = json.load(f)
-    assert validate_otherSites_length(data) == {
-        'level': 'error',
-        'dataPath': '.otherSitesDuration',
-        'message': 'must have the same length as otherSites'
-    }
-
-
 def test_validate_otherSites_cycleDuration_valid():
     with open(f"{fixtures_path}/cycle/otherSites/cycleDuration/valid.json") as f:
         data = json.load(f)
@@ -228,3 +212,26 @@ def test_validate_otherSites_cycleDuration_invalid():
         'dataPath': '.cycleDuration',
         'message': 'must be equal to the sum of siteDuration and otherSitesDuration'
     }
+
+
+def test_validate_possibleCoverCrop_valid():
+    # no products should be valid
+    assert validate_possibleCoverCrop({}) is True
+
+    with open(f"{fixtures_path}/cycle/coverCrop/valid.json") as f:
+        data = json.load(f)
+    assert validate_possibleCoverCrop(data) is True
+
+    with open(f"{fixtures_path}/cycle/coverCrop/valid-not-coverCrop.json") as f:
+        data = json.load(f)
+    assert validate_possibleCoverCrop(data) is True
+
+
+def test_validate_possibleCoverCrop_error():
+    with open(f"{fixtures_path}/cycle/coverCrop/invalid.json") as f:
+        data = json.load(f)
+    assert validate_possibleCoverCrop(data) == {
+        'level': 'error',
+        'dataPath': '',
+        'message': 'cover crop cycle contains non cover crop product'
+    }
