@@ -3,7 +3,7 @@ import json
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.measurement import (
-    validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
+    validate_soilTexture, validate_depths, validate_term_unique,
     validate_require_startDate_endDate, validate_with_models, validate_value_length, validate_required_depths
 )
 
@@ -151,33 +151,6 @@ def test_validate_depths_invalid():
     }
 
 
-def test_validate_measurement_value_valid():
-    # no measurements should be valid
-    assert validate_value_min_max([]) is True
-
-    with open(f"{fixtures_path}/measurement/min-max/value-valid.json") as f:
-        data = json.load(f)
-    assert validate_value_min_max(data.get('nodes')) is True
-
-
-def test_validate_measurement_value_invalid():
-    with open(f"{fixtures_path}/measurement/min-max/value-above.json") as f:
-        data = json.load(f)
-    assert validate_value_min_max(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.measurements[0].value',
-        'message': 'should be below 25000.0'
-    }
-
-    with open(f"{fixtures_path}/measurement/min-max/value-below.json") as f:
-        data = json.load(f)
-    assert validate_value_min_max(data.get('nodes')) == {
-        'level': 'error',
-        'dataPath': '.measurements[0].value',
-        'message': 'should be above 0.0'
-    }
-
-
 def test_validate_term_unique_valid():
     # no measurements should be valid
     assert validate_term_unique([]) is True
