@@ -4,14 +4,14 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.utils import _group_nodes, _hash_nodes
 from hestia_earth.validation.validators.shared import (
-    validate_dates, validate_list_dates, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_list_min_below_max, validate_list_min_max_lookup,
     validate_country, validate_region_in_country, validate_is_region, validate_area, validate_coordinates,
     need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
     validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
     validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size,
-    validate_private_has_source
+    validate_private_has_source, validate_list_value_between_min_max
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
@@ -90,14 +90,14 @@ def test_validate_emissions_dates_invalid():
     }
 
 
-def test_validate_list_min_max_valid():
+def test_validate_list_min_below_max_valid():
     node = {
         'list': [{
             'min': 10,
             'max': 100
         }]
     }
-    assert validate_list_min_max(node, 'list') is True
+    assert validate_list_min_below_max(node, 'list') is True
     node = {
         'list': [{
             'min': [
@@ -110,17 +110,17 @@ def test_validate_list_min_max_valid():
             ]
         }]
     }
-    assert validate_list_min_max(node, 'list') is True
+    assert validate_list_min_below_max(node, 'list') is True
 
 
-def test_validate_list_min_max_invalid():
+def test_validate_list_min_below_max_invalid():
     node = {
         'list': [{
             'min': 100,
             'max': 10
         }]
     }
-    assert validate_list_min_max(node, 'list') == {
+    assert validate_list_min_below_max(node, 'list') == {
         'level': 'error',
         'dataPath': '.list[0].max',
         'message': 'must be greater than min'
@@ -131,13 +131,95 @@ def test_validate_list_min_max_invalid():
             'max': [10, 20]
         }]
     }
-    assert validate_list_min_max(node, 'list') == {
+    assert validate_list_min_below_max(node, 'list') == {
         'level': 'error',
         'dataPath': '.list[0].max',
         'message': 'must be greater than min'
     }
 
 
+def test_validate_list_value_between_min_max_valid():
+    node = {
+        'list': [{
+            'min': 10,
+            'value': 50,
+            'max': 100
+        }]
+    }
+    assert validate_list_value_between_min_max(node, 'list') is True
+    node = {
+        'list': [{
+            'min': [
+                50,
+                10
+            ],
+            'value': [
+                55,
+                15
+            ],
+            'max': [
+                60,
+                20
+            ]
+        }]
+    }
+    assert validate_list_value_between_min_max(node, 'list') is True
+
+
+def test_validate_list_value_between_min_max_invalid():
+    node = {
+        'list': [{
+            'min': 0,
+            'value': 20,
+            'max': 10
+        }]
+    }
+    assert validate_list_value_between_min_max(node, 'list') == {
+        'level': 'error',
+        'dataPath': '.list[0].value',
+        'message': 'must be between min and max'
+    }
+    node = {
+        'list': [{
+            'min': [1, 10],
+            'value': [5, 200],
+            'max': [10, 20]
+        }]
+    }
+    assert validate_list_value_between_min_max(node, 'list') == {
+        'level': 'error',
+        'dataPath': '.list[0].value',
+        'message': 'must be between min and max'
+    }
+
+
+def test_validate_list_min_max_lookup_valid():
+    # no measurements should be valid
+    assert validate_list_min_max_lookup({}, 'measurements') is True
+
+    with open(f"{fixtures_path}/shared/min-max/value-valid.json") as f:
+        data = json.load(f)
+    assert validate_list_min_max_lookup(data, 'measurements') is True
+
+
+def test_validate_list_min_max_lookup_invalid():
+    with open(f"{fixtures_path}/shared/min-max/value-above.json") as f:
+        data = json.load(f)
+    assert validate_list_min_max_lookup(data, 'measurements') == {
+        'level': 'error',
+        'dataPath': '.measurements[0].value',
+        'message': 'should be below 25000.0'
+    }
+
+    with open(f"{fixtures_path}/shared/min-max/value-below.json") as f:
+        data = json.load(f)
+    assert validate_list_min_max_lookup(data, 'measurements') == {
+        'level': 'error',
+        'dataPath': '.measurements[0].value',
+        'message': 'should be above 0.0'
+    }
+
+
 def test_validate_country_valid():
     node = {
         'country': {
