@@ -3,7 +3,8 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.transformation import (
     validate_previous_transformation,
-    validate_first_transformation,
+    validate_first_transformation_fields,
+    validate_first_transformation_input,
     validate_transformation_excretaManagement
 )
 
@@ -45,25 +46,44 @@ def test_validate_previous_transformation_invalid():
     }
 
 
-def test_validate_first_transformation_valid():
+def test_validate_first_transformation_fields_valid():
     # no transformations should be valid
-    assert validate_first_transformation([]) is True
+    assert validate_first_transformation_fields([]) is True
 
-    with open(f"{fixtures_folder}/first-transformation/valid.json") as f:
+    with open(f"{fixtures_folder}/first-transformation-fields/valid.json") as f:
         data = json.load(f)
-    assert validate_first_transformation(data.get('nodes')) is True
+    assert validate_first_transformation_fields(data.get('nodes')) is True
 
 
-def test_validate_first_transformation_invalid():
-    with open(f"{fixtures_folder}/first-transformation/invalid.json") as f:
+def test_validate_first_transformation_fields_invalid():
+    with open(f"{fixtures_folder}/first-transformation-fields/invalid.json") as f:
         data = json.load(f)
-    assert validate_first_transformation(data.get('nodes')) == {
+    assert validate_first_transformation_fields(data.get('nodes')) == {
         'level': 'error',
         'dataPath': '.transformations[0].previousTransformationTerm',
         'message': 'must not be set on the first transformation'
     }
 
 
+def validate_first_transformation_input_valid():
+    # no transformations should be valid
+    assert validate_first_transformation_input({}, []) is True
+
+    with open(f"{fixtures_folder}/first-transformation-input/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_first_transformation_fields(cycle, cycle.get('transformations')) is True
+
+
+def test_validate_first_transformation_input_invalid():
+    with open(f"{fixtures_folder}/first-transformation-input/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_first_transformation_input(cycle, cycle.get('transformations')) == {
+        'level': 'error',
+        'dataPath': '.transformations[0]',
+        'message': 'at least one Input must be a Product of the Cycle'
+    }
+
+
 def test_validate_transformation_excretaManagement_valid():
     # no transformations should be valid
     assert validate_transformation_excretaManagement([])
